@@ -4,42 +4,41 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': 'python3 ./Parser/asdl_c.py',
- 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
- 'AST_ASDL': './Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-Wno-unused-result -fno-common -dynamic',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/bin',
- 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/bin',
+ 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5',
  'BLDLIBRARY': '',
- 'BLDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'BLDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-apple-darwin24.0.0',
  'BYTESTR_DEPS': '\\',
  'CC': '/usr/bin/clang',
  'CCSHARED': '',
- 'CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
  'CFLAGSFORSHARED': '',
+ 'CFLAGS_ALIASING': '-fno-strict-aliasing',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
- 'CONFIGURE_CPPFLAGS': '-I/opt/local/include/openssl-1.0 -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk',
- 'CONFIGURE_LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
- 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ' 'LDFLAGS=-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ' 'CPPFLAGS=-I/opt/local/include/openssl-1.0 -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk'",
- 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include',
- 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'CONFIGURE_CPPFLAGS': '-I/opt/local/libexec/openssl11/include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk',
+ 'CONFIGURE_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' '--with-ensurepip=no' '--with-system-expat' '--with-system-ffi' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk'",
+ 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/include',
+ 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/include/python3.5m',
  'COREPYTHONPATH': ':plat-darwin',
- 'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk',
+ 'COVERAGE_INFO': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10/coverage.info',
+ 'COVERAGE_REPORT': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
+ 'CPPFLAGS': '-I. -I./Include -I/opt/local/libexec/openssl11/include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk',
  'CXX': '/usr/bin/clang++',
- 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3 /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3 /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/lib-dynload',
- 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5 /opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5 /opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/lib-dynload',
+ 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
@@ -51,31 +50,31 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
+ 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '@EXTRAPLATDIR@',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.so',
+ 'EXT_SUFFIX': '.cpython-35m-darwin.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
+ 'GITBRANCH': '',
+ 'GITTAG': '',
+ 'GITVERSION': '',
  'GNULD': 'no',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': './Grammar/Grammar',
  'HAVE_ACCEPT4': 0,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 1,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 0,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
@@ -87,6 +86,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
  'HAVE_BROKEN_SEM_GETVALUE': 1,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 1,
  'HAVE_CHOWN': 1,
@@ -112,12 +112,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
  'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 0,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 0,
  'HAVE_EPOLL': 0,
  'HAVE_EPOLL_CREATE1': 0,
  'HAVE_ERF': 1,
@@ -154,12 +157,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 1,
  'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
+ 'HAVE_GETENTROPY': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 1,
@@ -178,6 +182,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 0,
  'HAVE_GETRESUID': 0,
  'HAVE_GETSID': 1,
@@ -188,6 +194,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 0,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
  'HAVE_IF_NAMEINDEX': 1,
@@ -218,9 +225,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
+ 'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
@@ -254,11 +264,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PAUSE': 1,
  'HAVE_PIPE2': 0,
  'HAVE_PLOCK': 0,
- 'HAVE_POLL': 0,
- 'HAVE_POLL_H': 0,
+ 'HAVE_POLL': 1,
+ 'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 0,
  'HAVE_POSIX_FALLOCATE': 0,
  'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTHREAD_ATFORK': 1,
@@ -275,6 +286,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
@@ -282,6 +294,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
+ 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -334,6 +347,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 0,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
@@ -347,7 +361,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRUCT_STAT_ST_GEN': 1,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYMLINKAT': 1,
  'HAVE_SYNC': 1,
@@ -357,6 +370,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 1,
  'HAVE_SYS_FILE_H': 1,
@@ -369,6 +383,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 0,
@@ -408,7 +423,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
  'HAVE_UNSETENV': 1,
- 'HAVE_USABLE_WCHAR_T': 1,
+ 'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 1,
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
@@ -421,73 +436,73 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WCSCOLL': 1,
  'HAVE_WCSFTIME': 1,
  'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': '',
- 'HGTAG': '',
- 'HGVERSION': '',
  'HOST_GNU_TYPE': 'x86_64-apple-darwin24.0.0',
- 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
- 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include',
- 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
+ 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/include /opt/local/Library/Frameworks/Python.framework/Versions/3.5/include /opt/local/Library/Frameworks/Python.framework/Versions/3.5/include/python3.5m /opt/local/Library/Frameworks/Python.framework/Versions/3.5/include/python3.5m',
+ 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/include',
+ 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/include/python3.5m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'Python.framework/Versions/3.3/Python',
+ 'INSTSONAME': 'Python.framework/Versions/3.5/Python',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': '/usr/bin/clang++ -bundle -undefined dynamic_lookup',
- 'LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
  'LDLAST': '',
- 'LDLIBRARY': 'Python.framework/Versions/3.3/Python',
+ 'LDLIBRARY': 'Python.framework/Versions/3.5/Python',
  'LDLIBRARYDIR': '',
- 'LDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
- 'LDVERSION': '3.3m',
+ 'LDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
- 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib',
- 'LIBFFI_INCLUDEDIR': '',
+ 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5',
+ 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib',
+ 'LIBFFI_INCLUDEDIR': '/opt/local/include',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/pkgconfig',
- 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/config-3.3m',
- 'LIBRARY': 'libpython3.3m.a',
+ 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/pkgconfig',
+ 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5/config-3.5m',
+ 'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': ' -ldl  -framework CoreFoundation',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': '/usr/bin/clang',
- 'LINKFORSHARED': '-framework CoreFoundation Python.framework/Versions/3.3/Python',
+ 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5/config-3.5m -lpython3.5m -ldl -framework CoreFoundation',
+ 'LIPO_32BIT_FLAGS': '',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
+ 'LLVM_PROF_MERGER': '/usr/bin/xcrun llvm-profdata merge -output=code.profclangd *.profclangr',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'darwin',
  'MACHDEPPATH': ':plat-darwin',
- 'MACHDEPS': 'plat-darwin @EXTRAPLATDIR@',
+ 'MACHDEPS': 'plat-darwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '15.0',
  'MAINCC': '/usr/bin/clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/share/man',
+ 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/share/man',
  'MKDIR_P': './install-sh -c -d',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools _operator _collections itertools atexit _stat time _locale _io zipimport faulthandler _tracemalloc _symtable xxsubtype',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/_tracemalloc.o Modules/hashtable.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '',
  'OBJECT_OBJS': '\\',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -502,13 +517,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-darwin',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing_fork test_multiprocessing_forkserver test_multiprocessing_main_handling test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
- 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
+ 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': '',
  'PYLONG_BITS_IN_DIGIT': 0,
@@ -519,30 +536,33 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '/opt/local/Library/Frameworks',
  'PYTHONPATH': ':plat-darwin',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk  -I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk  -DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk  -Werror=declaration-after-statement -I. -I./Include -I/opt/local/libexec/openssl11/include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk  -DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/opt/local/libexec/openssl11/include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
+ 'PY_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk ',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
+ 'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
- 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib',
+ 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10',
+ 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
  'SHLIBS': ' -ldl  -framework CoreFoundation',
  'SHLIB_SUFFIX': '.so',
  'SIGNAL_OBJS': '',
- 'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 1,
+ 'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
  'SIZEOF_FLOAT': 4,
@@ -561,12 +581,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SOABI': 'cpython-33m',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SOABI': 'cpython-35m-darwin',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '',
@@ -576,20 +596,20 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7 ./python',
+ 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7 ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10 ./python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_DEPS': '\\ \\',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 1,
- 'VERSION': '3.3',
+ 'VERSION': '3.5',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
@@ -602,9 +622,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
- 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
- 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/share',
- 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3',
- 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3',
+ 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10',
+ 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python35/python35/work/Python-3.5.10',
+ 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5/share',
+ 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5',
+ 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.5',
  'srcdir': '.'}
